Changelog for Falcon 4.1.0
==========================

Summary
-------

Falcon 4.1 is in development. The progress is tracked via the
`Version 4.1 milestone <https://github.com/falconry/falcon/milestone/41>`__
on GitHub.


Changes to Supported Platforms
------------------------------

- CPython 3.14 is now fully supported.
  (`#2413 <https://github.com/falconry/falcon/issues/2413>`__)
- Although the Falcon 4.x series is only guaranteed to support Python 3.10+,
  this release still supports 3.8 & 3.9 at runtime using the pure Python wheel.

  Falcon 4.2 is expected to drop the end-of-life Python 3.8 completely
  (but runtime support will continue for 3.9 on a best effort basis).


.. towncrier release notes start

Contributors to this Release
----------------------------

Many thanks to all of our talented and stylish contributors for this release!

- `aarcex3 <https://github.com/aarcex3>`__
- `AbduazizZiyodov <https://github.com/AbduazizZiyodov>`__
- `Bombaclath97 <https://github.com/Bombaclath97>`__
- `bssyousefi <https://github.com/bssyousefi>`__
- `CaselIT <https://github.com/CaselIT>`__
- `Cycloctane <https://github.com/Cycloctane>`__
- `diegomirandap <https://github.com/diegomirandap>`__
- `EricGoulart <https://github.com/EricGoulart>`__
- `jap <https://github.com/jap>`__
- `jkmnt <https://github.com/jkmnt>`__
- `kemingy <https://github.com/kemingy>`__
- `Krishn1412 <https://github.com/Krishn1412>`__
- `perodriguezl <https://github.com/perodriguezl>`__
- `Shreshth3 <https://github.com/Shreshth3>`__
- `vytas7 <https://github.com/vytas7>`__
- `webknjaz <https://github.com/webknjaz>`__
- `x612skm <https://github.com/x612skm>`__
